@@ -84,6 +84,8 @@ class KScoreDialog::KScoreDialogPrivate
         QString player;
         int lastHighPosition; /// remember the position to delete if the user wants to forget
 
+        QDialogButtonBox *buttonBox;
+
         //Q-Pointer
         KScoreDialogPrivate(KScoreDialog* parent):q(parent){}
         KScoreDialog* const q;
@@ -103,8 +105,8 @@ class KScoreDialog::KScoreDialogPrivate
 KScoreDialog::KScoreDialog(int fields, QWidget *parent)
     : QDialog(parent), d(new KScoreDialogPrivate(this))
 {
-    QLoggingCategory::setFilterRules(QLatin1Literal("games.highscore.debug = true"));
-    
+    QLoggingCategory::setFilterRules(QStringLiteral("games.highscore.debug = true"));
+
     setWindowTitle( i18n(DEFAULT_GROUP_NAME) );
     setModal( true );
     d->highscoreObject = new KHighscore();
@@ -120,15 +122,15 @@ KScoreDialog::KScoreDialog(int fields, QWidget *parent)
 
     //Set up the default table headers
     d->header[Name] = i18n("Name");
-    d->key[Name] = QLatin1String( "Name" );
+    d->key[Name] = QStringLiteral( "Name" );
     d->header[Date] = i18n("Date");
-    d->key[Date] = QLatin1String( "Date" );
+    d->key[Date] = QStringLiteral( "Date" );
     d->header[Level] = i18n("Level");
-    d->key[Level] = QLatin1String( "Level" );
+    d->key[Level] = QStringLiteral( "Level" );
     d->header[Score] = i18n("Score");
-    d->key[Score] = QLatin1String( "Score" );
+    d->key[Score] = QStringLiteral( "Score" );
     d->header[Time] = i18n("Time");
-    d->key[Time] = QLatin1String( "Time" );
+    d->key[Time] = QStringLiteral( "Time" );
 
     //d->page = new QWidget(this);
 
@@ -138,23 +140,13 @@ KScoreDialog::KScoreDialog(int fields, QWidget *parent)
     QVBoxLayout *mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
     mainLayout->addWidget(d->tabWidget);
-    
-    buttonBox = new QDialogButtonBox(this);
-    
-    if(d->newName.second == -1)
-    {
-      buttonBox->setStandardButtons(QDialogButtonBox::Close);
-      connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
-    }
-    else
-    {
-       buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-       connect(buttonBox, &QDialogButtonBox::accepted, this, &KScoreDialog::accept);
-       connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
-       connect(buttonBox, &QDialogButtonBox::accepted, this, &KScoreDialog::slotGotName);
-    }
-    
-    mainLayout->addWidget(buttonBox);
+
+    d->buttonBox = new QDialogButtonBox(this);
+
+    d->buttonBox->setStandardButtons(QDialogButtonBox::Close);
+    connect(d->buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
+
+    mainLayout->addWidget(d->buttonBox);
 }
 
 KScoreDialog::~KScoreDialog()
@@ -250,7 +242,6 @@ void KScoreDialog::hideField(int field)
 /*
 Create the widgets and layouts etc. for the dialog
 */
-
 void KScoreDialog::KScoreDialogPrivate::setupDialog()
 {
     nrCols = 1;
@@ -352,7 +343,6 @@ void KScoreDialog::KScoreDialogPrivate::setupGroup(const QByteArray& groupKey)
 /*
 Fill the dialog with the correct data
 */
-
 void KScoreDialog::KScoreDialogPrivate::aboutToShow()
 {
     if (!loaded)
@@ -463,7 +453,7 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
 {
     scores.clear();
 
-    QList<QByteArray> groupKeyList; //This will be a list of all the groups in the config fie
+    QList<QByteArray> groupKeyList; //This will be a list of all the groups in the config file
     foreach( const QString & groupString, highscoreObject->groupList())
     {
         groupKeyList << groupString.toUtf8(); //Convert all the QStrings to QByteArrays
@@ -481,7 +471,7 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
     foreach(const QByteArray &groupKey, groupKeyList)
     {
         highscoreObject->setHighscoreGroup(QLatin1String( groupKey ));
-        player = highscoreObject->readEntry(0, QLatin1String( "LastPlayer" ));  //FIXME
+        player = highscoreObject->readEntry(0, QStringLiteral( "LastPlayer" ));  //FIXME
 
         for (int i = 1; i <= 10; ++i)
         {
@@ -490,7 +480,7 @@ void KScoreDialog::KScoreDialogPrivate::loadScores()
             {
                 if (fields & field)
                 {
-                    score[field] = highscoreObject->readEntry(i, key[field], QLatin1String("-"));
+                    score[field] = highscoreObject->readEntry(i, key[field], QStringLiteral("-"));
                 }
             }
             scores[groupKey].append(score);
@@ -512,7 +502,7 @@ void KScoreDialog::KScoreDialogPrivate::saveScores()
 {
     highscoreObject->setHighscoreGroup(QLatin1String( configGroup ));
 
-    highscoreObject->writeEntry(0,QLatin1String( "LastPlayer" ), player);
+    highscoreObject->writeEntry(0,QStringLiteral( "LastPlayer" ), player);
 
     for (int i = 1; i <= 10; ++i)
     {
@@ -585,17 +575,15 @@ int KScoreDialog::addScore(const FieldInfo& newInfo, const AddScoreFlags& flags)
                 d->player=score[Name];
                 d->newName = QPair<QByteArray,int>(d->configGroup,i+1);
 
-		buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-		
-		buttonBox->button(QDialogButtonBox::Ok)->setText(i18n("&Remember"));
-		buttonBox->button(QDialogButtonBox::Cancel)->setText(i18n("&Forget"));
-		buttonBox->button(QDialogButtonBox::Ok)->setToolTip(i18n("Remember this high score"));
-		buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Forget this high score"));
-                
-                connect(buttonBox, &QDialogButtonBox::accepted, this, &KScoreDialog::accept);
-		connect(buttonBox, &QDialogButtonBox::accepted, this, &KScoreDialog::slotGotName);
-		connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
-		connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::slotForgetScore);
+                d->buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+
+                d->buttonBox->button(QDialogButtonBox::Ok)->setText(i18n("&Remember"));
+                d->buttonBox->button(QDialogButtonBox::Cancel)->setText(i18n("&Forget"));
+                d->buttonBox->button(QDialogButtonBox::Ok)->setToolTip(i18n("Remember this high score"));
+                d->buttonBox->button(QDialogButtonBox::Cancel)->setToolTip(i18n("Forget this high score"));
+
+                connect(d->buttonBox, &QDialogButtonBox::accepted, this, &KScoreDialog::slotGotName);
+                connect(d->buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::slotForgetScore);
             }
             else
                 d->saveScores();
@@ -659,11 +647,9 @@ void KScoreDialog::slotGotName()
     d->scores[d->configGroup].removeAt(10);
     d->comment.clear();  // hide the congratulations
     d->commentLabel->hide();
-    
-    delete buttonBox;
-    buttonBox = new QDialogButtonBox(this);
-    buttonBox->setStandardButtons(QDialogButtonBox::Close);
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
+
+    d->buttonBox->setStandardButtons(QDialogButtonBox::Close);
+    connect(d->buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
 }
 
 void KScoreDialog::slotForgetScore()
@@ -680,11 +666,9 @@ void KScoreDialog::slotForgetScore()
     d->scores[d->configGroup].removeAt(d->lastHighPosition);
     d->comment.clear();
     d->commentLabel->hide();
-    
-    delete buttonBox;
-    buttonBox = new QDialogButtonBox(this);
-    buttonBox->setStandardButtons(QDialogButtonBox::Close);
-    connect(buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
+
+    d->buttonBox->setStandardButtons(QDialogButtonBox::Close);
+    connect(d->buttonBox, &QDialogButtonBox::rejected, this, &KScoreDialog::reject);
 }
 
 
@@ -708,5 +692,3 @@ void KScoreDialog::keyPressEvent(QKeyEvent *ev)
     }
     QDialog::keyPressEvent(ev);
 }
-
-
