@@ -22,6 +22,7 @@
 #include <QtCore/QFileInfo>
 #include <QtCore/QStandardPaths>
 #include <QLoggingCategory>
+#include <QGuiApplication>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -58,7 +59,7 @@ KgThemeProvider::KgThemeProvider(const QByteArray& configKey, QObject* parent)
 	: QObject(parent)
 	, d(new Private(this, configKey))
 {
-	QLoggingCategory::setFilterRules(QLatin1Literal("games.lib.debug = true"));
+	QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
 	
 	qRegisterMetaType<const KgTheme*>();
 	qRegisterMetaType<KgThemeProvider*>();
@@ -282,7 +283,10 @@ void KgThemeProvider::rediscoverThemes()
 
 QPixmap KgThemeProvider::generatePreview(const KgTheme* theme, const QSize& size)
 {
-	return QPixmap(theme->previewPath()).scaled(size, Qt::KeepAspectRatio);
+	const qreal dpr = qApp->testAttribute(Qt::AA_UseHighDpiPixmaps) ? qApp->devicePixelRatio() : 1;
+	QPixmap pixmap = QPixmap(theme->previewPath()).scaled(size * dpr, Qt::KeepAspectRatio);
+	pixmap.setDevicePixelRatio(dpr);
+	return pixmap;
 }
 
 void KgThemeProvider::setDeclarativeEngine(const QString& name, QQmlEngine* engine)
